odooup
======

.. image:: https://img.shields.io/badge/license-LGPL--3-blue.svg
   :target: http://www.gnu.org/licenses/lgpl-3.0-standalone.html
   :alt: License: LGPL-3
.. image:: https://badge.fury.io/py/odooup.svg
    :target: http://badge.fury.io/py/odooup

``odooup`` is your best Odoo project compaion. Don't ask for docs, just
try it out. It is self-explanatory *and* self-exploratory.

.. contents::

Quickstart
~~~~~~~~~~
.. code:: bash

  $ pip install odooup
  $ odooup init


Useful links
~~~~~~~~~~~~

- dockery-odoo: https://xoe-labs.github.io/dockery-odoo/
- dodoo: https://github.com/xoe-labs/dodoo
- dodoo migrator: https://github.com/xoe-labs/dodoo-migrator
- dodoo initializer: https://github.com/xoe-labs/dodoo-initializer
- report issues at: https://github.com/xoe-labs/odooup/issues

.. _dodoo: https://pypi.python.org/pypi/dodoo

Credits
~~~~~~~

Contributors:

- David Arnold (XOE_)
- Deiber Rincón (XOE_)
- Yan Chirino (XOE_)
- Vladislav Shepilov (SHEPI_)
- Ildar Nasyrov (ITPP_)

.. _XOE: https://xoe.solutions
.. _SHEPI: https://github.com/shepilov-vladislav
.. _ITPP: https://www.it-projects.info

Maintainer
~~~~~~~~~~

.. image:: https://erp.xoe.solutions/logo.png
   :alt: XOE Corp. SAS
   :target: https://xoe.solutions

This project is maintained by XOE Copr. SAS.
